@@ -1,4 +1,4 @@
-/*	$Id: Class1.h 1106 2012-06-18 23:50:58Z faxguy $ */
+/*	$Id: Class1.h,v 1.55 2008/10/01 20:06:51 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -42,7 +42,6 @@ typedef struct {
     u_short	sr;	// T.30 DCS signalling rate
     u_char	mod;	// modulation technique
     bool	ok;	// true if modem is capable
-    u_short	num;	// distinct, incremental numbering
 } Class1Cap;
 #define	HasShortTraining(c) \
     ((c)->mod == V17 && ((c)->value & 1) && (c)[1].ok)
@@ -64,17 +63,12 @@ protected:
     bool	hadV17Trouble;		// indicates failure due to V.17 problems
     bool	batchingError;		// indicates failure due to batching protocol
     bool	jbigSupported;		// whether or not JBIG is supported in this mode
-    bool	senderHasV17Trouble;	// whether or not a sender has trouble with V.17
-    bool	senderSkipsV29;		// whether or not a sender skips over V.29 usage
-    int		dataSent;		// how much data the sender transmitted
-    int		dataMissed;		// how much data from the sender was missed
     const u_char* frameRev;		// HDLC frame bit reversal table
     fxStr	lid;			// encoded local id string
     fxStr	pwd;			// transmit password
     fxStr	sub;			// transmit subaddress
     Class1Cap	xmitCaps[15];		// modem send capabilities
     Class1Cap	recvCaps[15];		// modem recv capabilities
-    u_int	capsUsed;		// which modulations+bitrates were used in the session
     const Class1Cap* curcap;		// capabilities being used
     u_int	discap;			// DIS signalling rate capabilities
     u_int	prevPage;		// count of previous pages received
@@ -135,13 +129,13 @@ protected:
     void	checkReceiverDIS(Class2Params&);
     bool	dropToNextBR(Class2Params&);
     bool	raiseToNextBR(Class2Params&);
-    bool	sendTraining(Class2Params&, int, fxStr& emsg);
+    bool	sendTraining(Class2Params&, int, Status& eresult);
     bool	sendTCF(const Class2Params&, u_int ms);
-    bool	sendPage(TIFF* tif, Class2Params&, u_int, u_int, fxStr& emsg);
-    bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev, bool ecm, fxStr& emsg);
-    bool	sendRTC(Class2Params params, u_int ppmcmd, uint32 rowsperstrip, fxStr& emsg);
-    bool	sendPPM(u_int ppm, HDLCFrame& mcf, fxStr& emsg);
-    bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
+    bool	sendPage(TIFF* tif, Class2Params&, u_int, u_int, Status& eresult, bool cover);
+    bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev, bool ecm, Status& eresult);
+    bool	sendRTC(Class2Params params, u_int ppmcmd, uint32 rowsperstrip, Status& eresult);
+    bool	sendPPM(u_int ppm, HDLCFrame& mcf, Status& eresult);
+    bool	decodePPM(const fxStr& pph, u_int& ppm, Status& eresult);
 // reception support
     const AnswerMsg* findAnswer(const char*);
     bool	recvIdentification(
@@ -150,15 +144,14 @@ protected:
 		    u_int f3, const fxStr& nsf,
 		    u_int f4, const fxStr& id,
 		    u_int f5, FaxParams& dics,
-		    u_int timer, bool notransmit, fxStr& emsg);
+		    u_int timer, bool notransmit, Status& eresult);
     bool	recvDCSFrames(HDLCFrame& frame);
     bool	recvTraining();
-    bool	recvPPM(int& ppm, fxStr& emsg);
-    bool	recvPageData(TIFF*, fxStr& emsg);
-    bool	raiseRecvCarrier(bool& dolongtrain, fxStr& emsg);
+    bool	recvPPM(int& ppm, Status& eresult);
+    bool	recvPageData(TIFF*, Status& eresult);
+    bool	raiseRecvCarrier(bool& dolongtrain, Status& eresult);
     void	recvData(TIFF*, u_char* buf, int n);
     void	processDCSFrame(const HDLCFrame& frame);
-    void	processNewCapabilityUsage();
     void	abortPageRecv();
 // miscellaneous
     enum {			// Class 1-specific AT responses
@@ -168,7 +161,7 @@ protected:
     virtual ATResponse atResponse(char* buf, long ms = 30*1000);
     virtual bool waitFor(ATResponse wanted, long ms = 30*1000);
     virtual bool atCmd(const fxStr& cmd, ATResponse = AT_OK, long ms = 30*1000);
-    bool	switchingPause(fxStr& emsg, u_int times = 1);
+    bool	switchingPause(Status& eresult, u_int times = 1);
     void	encodeTSI(fxStr& binary, const fxStr& ascii);
     void	encodeNSF(fxStr& binary, const fxStr& ascii);
     const fxStr& decodeTSI(fxStr& ascii, const HDLCFrame& binary);
@@ -192,7 +185,7 @@ protected:
     bool	sendRawFrame(HDLCFrame& frame);
     bool	sendClass1Data(const u_char* data, u_int cc, const u_char* bitrev, bool eod, long ms);
     bool	sendClass1ECMData(const u_char* data, u_int cc,
-		     const u_char* bitrev, bool eod, u_int ppmcmd, fxStr& emsg);
+		     const u_char* bitrev, bool eod, u_int ppmcmd, Status& eresult);
     bool	recvFrame(HDLCFrame& frame, u_char dir, long ms = 10*1000, bool readPending = false, bool docrp = true, bool usehooksensitivity = true);
     bool	recvTCF(int br, HDLCFrame&, const u_char* bitrev, long ms);
     bool	recvRawFrame(HDLCFrame& frame);
@@ -200,10 +193,10 @@ protected:
     bool        waitForDCEChannel(bool awaitctrl);
     bool        renegotiatePrimary(bool constrain);
     bool	syncECMFrame();
-    void	abortPageECMRecv(TIFF* tif, const Class2Params& params, u_char* block, u_int fcount, u_short seq, bool pagedataseen, fxStr& emsg);
-    bool	recvPageECMData(TIFF* tif, const Class2Params& params, fxStr& emsg);
+    void	abortPageECMRecv(TIFF* tif, const Class2Params& params, u_char* block, u_int fcount, u_short seq, bool pagedataseen);
+    bool	recvPageECMData(TIFF* tif, const Class2Params& params, Status& eresult);
     void	blockData(u_int byte, bool flag);
-    bool	blockFrame(const u_char* bitrev, bool lastframe, u_int ppmcmd, fxStr& emsg);
+    bool	blockFrame(const u_char* bitrev, bool lastframe, u_int ppmcmd, Status& eresult);
     bool	endECMBlock();
     void	abortReceive();
     void	traceHDLCFrame(const char* direction, const HDLCFrame& frame, bool isecm = false);
@@ -216,32 +209,31 @@ public:
     void	hangup();
 
 // send support
-    bool	sendSetup(FaxRequest&, const Class2Params&, fxStr& emsg);
-    CallStatus	dialResponse(fxStr& emsg);
-    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&);
+    bool	sendSetup(FaxRequest&, const Class2Params&, Status& eresult);
+    CallStatus	dialResponse(Status& eresult);
+    FaxSendStatus getPrologue(Class2Params&, bool&, Status& eresult, u_int&);
     void	sendBegin();
-    void	getDataStats(FaxSetup* setupinfo);
     void	sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, fxStr& emsg, u_int& batched, u_short& npages);
+		    fxStr& pph, Status& eresult, u_int& batched, PageType pt);
     void	sendEnd();
     void	sendAbort();
 
 // receive support
-    CallType	answerCall(AnswerType, fxStr& emsg, const char* number);
+    CallType	answerCall(AnswerType, Status& eresult, const char* number);
     FaxParams	modemDIS() const;
     bool	setupReceive();
-    bool	recvBegin(FaxSetup* setupinfo, fxStr& emsg);
-    bool	recvEOMBegin(FaxSetup* setupinfo, fxStr& emsg);
-    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg, const fxStr& id);
-    bool	recvEnd(FaxSetup* setupinfo, fxStr& emsg);
+    bool	recvBegin(Status& eresult);
+    bool	recvEOMBegin(Status& eresult);
+    bool	recvPage(TIFF*, u_int& ppm, Status& eresult, const fxStr& id);
+    bool	recvEnd(Status& eresult);
     void	recvAbort();
     void	pokeConfig(bool isSend);
 
 // polling support
-    bool	requestToPoll(fxStr&);
+    bool	requestToPoll(Status& eresult);
     bool	pollBegin(const fxStr& cig, const fxStr& sep, const fxStr& pwd,
-		    fxStr& emsg);
+		    Status& eresult);
 
 // miscellaneous
     bool	faxService(bool enableV34, bool enableV17);	// switch to fax mode (send)
