@@ -1,4 +1,4 @@
-/*	$Id: Class2.h 1106 2012-06-18 23:50:58Z faxguy $ */
+/*	$Id: Class2.h,v 1.27 2008/10/01 20:06:52 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -84,14 +84,14 @@ protected:
 // transmission support
     bool	dataTransfer();
     bool	sendRTC(Class2Params params);
-    bool	sendPageData(TIFF* tif, u_int pageChop);
+    bool	sendPageData(TIFF* tif, u_int pageChop, bool cover);
 
-    virtual bool sendPage(TIFF* tif, u_int pageChop) = 0;
+    virtual bool sendPage(TIFF* tif, u_int pageChop, bool cover) = 0;
     virtual bool pageDone(u_int ppm, u_int& ppr) = 0;
 // reception support
     const AnswerMsg* findAnswer(const char*);
     bool	recvDCS(const char*);
-    bool	recvPageData(TIFF*, fxStr& emsg);
+    bool	recvPageData(TIFF*, Status& eresult);
     bool	recvPPM(TIFF*, int& ppr);
     bool	parseFPTS(TIFF*, const char* cp, int& ppr);
     void	abortPageRecv();
@@ -119,7 +119,8 @@ protected:
 // hangup processing
     void	processHangup(const char*);
     bool	isNormalHangup();
-    const char*	hangupCause(const char* code, bool codetocode = false);
+    const char*	hangupCause(const char* code);
+    const Status&	hangupStatus(const char* code);
     void	tracePPR(const char* dir, u_int ppr);
     void	tracePPM(const char* dir, u_int ppm);
 // class 2 command support routines
@@ -139,27 +140,26 @@ public:
     virtual ~Class2Modem();
 
 // send support
-    bool	sendSetup(FaxRequest&, const Class2Params&, fxStr& emsg);
-    CallStatus	dialResponse(fxStr& emsg);
-    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&);
+    bool	sendSetup(FaxRequest&, const Class2Params&, Status& eresult);
+    CallStatus	dialResponse(Status& eresult);
+    FaxSendStatus getPrologue(Class2Params&, bool&, Status& eresult, u_int&);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, fxStr& emsg, u_int& batched, u_short& npages);
+		    fxStr& pph, Status& eresult, u_int& batched, PageType pt);
     void	sendAbort();
-    void	getDataStats(FaxSetup* setupinfo);
 
 // receive support
     bool	setupReceive();
-    bool	recvBegin(FaxSetup* setupinfo, fxStr& emsg);
-    bool	recvEOMBegin(FaxSetup* setupinfo, fxStr& emsg);
-    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg, const fxStr& id);
-    bool	recvEnd(FaxSetup* setupinfo, fxStr& emsg);
+    bool	recvBegin(Status& eresult);
+    bool	recvEOMBegin(Status& eresult);
+    bool	recvPage(TIFF*, u_int& ppm, Status& eresult, const fxStr& id);
+    bool	recvEnd(Status& eresult);
     void	recvAbort();
     void	pokeConfig(bool isSend);
 
 // polling support
-    bool	requestToPoll(fxStr& emsg);
+    bool	requestToPoll(Status& eresult);
     bool	pollBegin(const fxStr& cig, const fxStr& sep, const fxStr& pwd,
-		    fxStr& emsg);
+		    Status& eresult);
 
 // miscellaneous
     bool	faxService(bool enableV34, bool enableV17);	// switch to fax mode (send)
