@@ -1,4 +1,4 @@
-/*	$Id: Class20.h,v 1.1.1.1 2005/11/11 21:32:02 faxguy Exp $ */
+/*	$Id: Class20.h,v 1.3 2008/10/01 20:06:52 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -33,7 +33,7 @@
 class Class20Modem : public Class2Modem {
 protected:
 // transmission support
-    bool	sendPage(TIFF* tif, u_int pageChop);
+    bool	sendPage(TIFF* tif, u_int pageChop, bool cover);
     bool	pageDone(u_int ppm, u_int& ppr);
 
     void	abortDataTransfer();
