@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h 1114 2012-07-02 18:27:37Z faxguy $ */
+/*	$Id: ClassModem.h,v 1.31 2008/11/21 20:55:47 pfournier Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -31,6 +31,7 @@
 #include <stdarg.h>
 #include "Str.h"
 #include "CallID.h"
+#include "Status.h"
 
 class ModemServer;
 class ModemConfig;
@@ -98,8 +99,7 @@ public:
 	FAILURE	   = 6,		// other problem (e.g. modem turned off)
 	NOFCON	   = 7,		// carrier established, but phase a failure
 	DATACONN   = 8,		// data carrier established
-	RING	   = 9,		// glare - ring detected after dial
-	V34FAIL	   = 10		// V.34 handshake failure
+	RING	   = 9		// glare - ring detected after dial
     };
 
     enum {			// ClassModem::CallType
@@ -205,7 +205,7 @@ protected:
     fxStr	revQueryCmd;	// product revision identification command
 
     static const char* serviceNames[9];	 // class 2 services
-    static const char* callStatus[11];	 // printable call status
+    static Status callStatus[10];	 // printable call status
     static const char* ATresponses[19];
 
     ClassModem(ModemServer&, const ModemConfig&);
@@ -220,8 +220,8 @@ protected:
     bool doQuery(const fxStr& queryCmd, fxStr& result, long ms = 30*1000);
 // dial/answer interactions with derived classes
     virtual const AnswerMsg* findAnswer(const char* s);
-    virtual CallType answerResponse(fxStr, fxStr& emsg);
-    virtual CallStatus dialResponse(fxStr& emsg) = 0;
+    virtual CallType answerResponse(const fxStr&, Status& eresult);
+    virtual CallStatus dialResponse(Status& eresult) = 0;
     virtual bool isNoise(const char*);
 // miscellaneous
     void	modemSupports(const char* fmt, ...);
@@ -248,13 +248,8 @@ public:
     const fxStr& getRevision() const;
     fxStr	getCapabilities() const;
     u_int	getModemServices() const;
-    bool	doCallIDDisplay(int i) const;
-    bool	doCallIDRecord(int i) const;
-    const fxStr& getCallIDLabel(int i) const;
-    const fxStr& getCallIDType(int i) const;
 // data transfer timeout controls
     void	setDataTimeout(long secs, u_int br);
-    void	setDataTimeout(long datasize, int discount, u_int br);
     long	getDataTimeout() const;
 // miscellaneous
     void	pause(u_int ms);
@@ -268,11 +263,10 @@ public:
     void	beginTimedTransfer();
     void	endTimedTransfer();
     bool	wasTimeout();
-    bool	wasModemError();
     void	setTimeout(bool);
     void	flushModemInput();
     bool	putModem(void* data, int n, long ms = 0);
-    bool	putModemData(void* data, int n, long ms = -1);
+    bool	putModemData(void* data, int n);
     bool	putModemDLEData(const u_char* data, u_int,
 		    const u_char* brev, long ms, bool doquery = false);
     bool	putModemLine(const char* cp, long ms = 0);
@@ -305,23 +299,24 @@ public:
     FlowControl	getOutputFlow();
 // server-related stuff
     bool	abortRequested();
+    Status	abortReason();
 
     /*
      * Send support:
      *
-     * if (dial(number, origin, emsg) == OK) {
+     * if (dial(number, params, eresult) == OK) {
      *	  ...do stuff...
      * }
      * hangup();
      */
     virtual bool dataService();
-    virtual CallStatus dial(const char* number, const char* origin, fxStr& emsg);
+    virtual CallStatus dial(const char* number, Status& eresult);
 
     /*
      * Receive support:
      *
      * if (waitForRings(nrings, ctype, cid)) {	// wait before answering phone
-     *    case (answerCall(type, emsg)) {
+     *    case (answerCall(type, eresult)) {
      *    CALLTYPE_FAX:
      *	        ...do fax kinds of things...
      *      break;
@@ -338,8 +333,13 @@ public:
      * at any time in this procedure.
      */
     virtual bool waitForRings(u_short rings, CallType&, CallID&);
-    virtual CallType answerCall(AnswerType, fxStr& emsg, const char* dialnumber = NULL);
+    virtual CallType answerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
     virtual void answerCallCmd(CallType);
+
+    /*
+     * Voice support
+     */
+    virtual void playFile (u_int id);
 };
 inline long ClassModem::getDataTimeout() const		{ return dataTimeout; }
 inline const fxStr& ClassModem::getModel() const	{ return modemModel; }
