@@ -1,4 +1,4 @@
-/*	$Id: FaxRequest.h 1108 2012-06-26 03:56:56Z faxguy $ */
+/*	$Id: FaxRequest.h,v 1.18 2008/10/01 20:06:52 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -33,8 +33,11 @@
 #include <time.h>
 #include <stdio.h>
 
+#include "Status.h"
+
 class Class2Params;
 
+
 /*
  * This structure is passed from the queue manager
  * to the fax modem+protocol service for each job
@@ -98,10 +101,6 @@ public:
 	const char* name;
 	u_short FaxRequest::* p;
     };
-    struct intval {
-	const char* name;
-	int FaxRequest::* p;
-    };
 
     fxStr	qfile;		// associated queue file name
     fxStr	jobid;		// job identifier
@@ -112,15 +111,12 @@ public:
     u_short	state;		// job scheduling state
     u_short	lineno;		// line number when reading queue file
     FaxSendStatus status;	// request status indicator
-    u_short	totpages;	// total cumulative pages in documents
+    u_short	totpages;	// total cummulative pages in documents
+    u_short	skippages;	// skipped pages in documents
+    u_short	coverpages;	// number of cover pages 1st
     u_short	npages;		// total pages sent/received
-    u_short	skippages;	// skip over these pages in the document
-    int		skippedpages;	// start page numbering here + 1
-    u_short	serverdocover;	// server should create the coverpage
-    u_short	nocountcover;	// don't count these pages
-    u_short	probeonly;	// this job is only to probe the receiver
-    u_short	conntime;	// connection time on last session
-    u_short	duration;	// duration time on last session
+    u_short	nskip;		// total pages skipped so far
+    u_short	ncover;		// cover pages sent so far
     u_short	ntries;		// # tries to send current page
     u_short	ndials;		// # consecutive failed tries to call dest
     u_short	totdials;	// total # calls to dest
@@ -140,10 +136,8 @@ public:
     u_short	desiredtl;	// desired tagline handling
     u_short	useccover;	// whether to use continuation cover page
     u_short	usexvres;	// whether to use extended VR
-    u_short	usecolor;	// whether to use color
     u_short	pagechop;	// whether to do page chopping
     u_short	notify;		// email notification flags
-    u_short	ignoremodembusy;// ignore modem busy status
     float	chopthreshold;	// minimum white space before chopping
     time_t	tts;		// time to send
     time_t	killtime;	// time to kill job
@@ -154,13 +148,9 @@ public:
     fxStr	number;		// dialstring for fax machine
     fxStr	subaddr;	// transmit subaddress
     fxStr	passwd;		// transmit password
-    fxStr	canonical;	// canonical phone number for data correlation
     fxStr	external;	// displayable phone number for fax machine
-    fxStr	notice;		// message to send for notification
-    fxStr	modem;		// outgoing modem (ModemGroup) to use
-    fxStr	modemused;	// specific modem used in last attempt
+    fxStr	modem;		// outgoing modem to use
     fxStr	faxnumber;	// Sender's number to advertise to phone company
-    fxStr	faxname;	// Sender's name to advertise to phone company
     fxStr	tsi;		// TSI to use instead of LocalIdentifier
     fxStr	pagehandling;	// page analysis information
     fxStr	receiver;	// receiver's identity for cover page generation
@@ -181,15 +171,12 @@ public:
     fxStr	doneop;		// operation to do when job completes
     fxStr	csi;		// CSI string from receiving equipment (ASCII representation)
     fxStr	nsf;		// NSF string from receiving equipment (ASCII representation)
-    fxStr	timeofday;	// time of day restrictions
-    fxStr	timezone;	// timezone to use in tag line
-    fxStr	errorcode;	// error code for status
+    fxStr	pagerange;	// Range of pages to send (if set)
     pid_t	writeQFilePid;	// pid of last writeQFile operation
     FaxItemArray items;	// set of requests
 
     static stringval strvals[];
     static shortval shortvals[];
-    static intval intvals[];
     static const char* opNames[18];
     static const char* notifyVals[4];
     static const char* chopVals[4];
@@ -201,11 +188,8 @@ public:
     void writeQFile();
     u_int findItem(FaxSendOp, u_int start = 0) const;
 
-    bool isNotify(u_int what) const;
-
     static bool isStrCmd(const char* cmd, u_int& ix);
     static bool isShortCmd(const char* cmd, u_int& ix);
-    static bool isIntCmd(const char* cmd, u_int& ix);
 
     void insertFax(u_int ix, const fxStr& file);
     void addItem(FaxSendOp op, char* tag);
@@ -216,7 +200,14 @@ public:
     static fxStr mkbasedoc(const fxStr& file);
     void renameSaved(u_int fi);
     bool isUnreferenced(u_int fi);
+
+    Status result;
+
+#if 0
+private:
+    fxStr	notice;		// message to send for notification
+    fxStr	code;		// code relating to notice
+#endif
 };
-inline bool FaxRequest::isNotify(u_int what) const
-    { return (notify & (u_short) what) != 0; }
+
 #endif /* _FaxRequest_ */
