@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h 1105 2012-06-14 17:57:49Z faxguy $ */
+/*	$Id: ModemConfig.h,v 1.65 2008/10/01 20:06:52 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,16 +32,13 @@
 #include "FaxModem.h"
 
 #include "Array.h"
+#include "StrArray.h"
 
 class id_config
 {
     public:
 	fxStr	pattern;
 	int	answerlength;
-	bool	display;
-	fxStr	label;
-	bool	record;
-	fxStr	type;
 
 	int compare (const id_config* n) const
 	{
@@ -87,8 +84,6 @@ public:
     fxStr	resetCmds;		// extra modem reset commands for start of initialization
     fxStr	readyCmds;		// extra modem reset commands for end of initialization
     fxStr	dialCmd;		// cmd for dialing (%s for number)
-    fxStr	setOriginCmd;		// cmd for setting the origination id (%s for name, %d for number)
-    fxStr	answerAgainCmd;		// cmd for answering after a missed answer command
     fxStr	answerAnyCmd;		// cmd for answering unknown call type
     fxStr	answerDataCmd;		// cmd for answering data call
     fxStr	answerFaxCmd;		// cmd for answering fax call
@@ -174,8 +169,6 @@ public:
     u_int	class1ECMFrameSize;	// ECM frame size for transmission
     u_int	class1PageLengthSupport;// page length support
     u_int	class1PageWidthSupport;	// page width support
-    u_int	class1RestrictPoorSenders;// restrict senders with poor audio from certain features
-    bool	class1ECMCheckFrameLength;// check frame length and not just CRC
     bool	class1GreyJPEGSupport;	// Greyscale JPEG support
     bool	class1ColorJPEGSupport;	// Full-color JPEG support
     bool	class1ECMSupport;	// support T.30-A ECM
@@ -191,7 +184,6 @@ public:
     fxStr	class2CQQueryCmd;	// cmd to query copy quality checking
     fxStr	class2BORCmd;		// cmd to set bit order
     fxStr	class2DisableV17Cmd;	// cmd to disable V.17 support
-    fxStr	class2DisableV34Cmd;	// cmd to disable V.34 support
     fxStr	class2RELCmd;		// cmd to enable byte-aligned EOL
     fxStr	class2CQCmd;		// cmd to setup copy quality checking
     fxStr	class2AbortCmd;		// cmd to abort a session
@@ -246,8 +238,8 @@ public:
     bool	softRTFCC;		// real-time fax compression conversion (software)
     bool	waitForConnect;		// modem sends multiple answer responses
     fxStr	tagLineFmt;		// format string for tag lines
-    fxStr	tagLineLocale;		// locale for tag lines
     fxStr	tagLineFontFile;	// font file for imaging tag lines
+    fxStr	tagLineCoverNumString;	// format string for tagline cover page numbers
     u_int	recvDataFormat;		// received facsimile data format
     bool	useJobTagLine;		// Use Job tagline or use conf taglineformat
     bool	raiseATCmd;		// whether or not to raise-case the AT commands
@@ -256,10 +248,11 @@ public:
     RTNHandling rtnHandling;            // RTN signal handling method
     BadPageHandling badPageHandling;	// bad page (received) handling method
     JBIGSupport	class1JBIGSupport;	// monochrome JBIG support
-    JBIGSupport	class2JBIGSupport;	// monochrome JBIG support
     bool	saveUnconfirmedPages;	// don't delete unconfirmed pages
-    fxStr	tiff2faxCmd;		// for intelligent RTFCC in comparing compression rates
+    bool	countSkippedPages;	// count (or nor) and notify skipped pages
     
+    fxStrArray	playList;		// List of files for ESC_PLAY
+
     					// Distinctive ring data as sequences of DRON/DROF intervals
     struct {
     	int cadence[5];                 // the ring cadence as a five-dimensional vector
