@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h 1147 2013-02-19 17:55:54Z faxguy $ */
+/*	$Id: ModemServer.h,v 1.17 2008/11/21 20:55:47 pfournier Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -64,7 +64,6 @@ private:
     FILE*	statusFile;		// server status file
     bool	deduceComplain;		// if true, complain when can't deduce
     bool	changePriority;		// change process priority by state
-    bool	noFailBusy;		// don't increment dials counters if busy
     bool	delayConfig;		// suppress effects while reading config
     fxStr	dialRulesFile;		// dial string rules filename
     fxStr	commid;			// communication ID
@@ -75,7 +74,6 @@ private:
     ClassModem*	modem;			// modem driver
     Timeout	timer;			// timeout support class
     bool	timeout;		// timeout during i/o operations
-    bool	modemerror;		// modem error during i/o operations
     fxStr	configFile;		// pathname to configuration file
     BaudRate	curRate;		// current termio baud rate
     Parity	curParity;		// current termio parity setting
@@ -123,6 +121,7 @@ protected:
     };
     ModemServerState state;
     bool	abortCall;		// abort current send/receive
+    Status	abortCallReason;	// reason for abort
 // logging and tracing
     FaxMachineLog* log;			// current log device
 
@@ -147,7 +146,6 @@ protected:
     bool	didBlockEnd();
     void	resetBlock();
     bool	isModemInput() const;
-    bool	isBusyNoFail() const;
     void	flushModemInput();
     bool	putModem(const void* data, int n, long ms = 0);
     bool	putModem1(const void* data, int n, long ms = 0);
@@ -164,12 +162,12 @@ protected:
     bool	modemStopOutput();
 // modem driver interfaces
     bool	modemWaitForRings(u_short rings, CallType&, CallID&);
-    CallType	modemAnswerCall(AnswerType, fxStr&, const char* dialnumber = NULL);
+    CallType	modemAnswerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
     void	modemAnswerCallCmd(CallType);
     void	modemFlushInput();
     void	modemHangup();
 // server state and related control interfaces
-    void	changeState(ModemServerState, long timeout = 0, const char* msg = NULL);
+    void	changeState(ModemServerState, long timeout = 0);
     void	setServerStatus(const char* fmt, ...);
     void	setProcessPriority(ModemServerState s);
 // system logging interfaces
@@ -195,11 +193,10 @@ protected:
     void	beginSession(const fxStr& number);
     void	endSession();
 // abort send/receive session
-    virtual void abortSession();
+    virtual void abortSession(Status reason);
     bool	abortRequested();
+    Status	abortReason();
 public:
-    const char* readyStateMsg;
-
     virtual ~ModemServer();
 
     virtual void open();
@@ -234,7 +231,5 @@ inline const fxStr& ModemServer::getModemNumber() const
 inline const fxStr& ModemServer::getCommID() const	{ return commid; }
 inline bool ModemServer::isModemInput() const
     { return rcvNext < rcvCC; }
-inline bool ModemServer::isBusyNoFail() const
-    { return noFailBusy; }
 
 #endif /* _ModemServer_ */
