@@ -1,4 +1,4 @@
-/*	$Id: faxSendApp.h,v 1.1.1.1 2005/11/11 21:32:02 faxguy Exp $ */
+/*	$Id: faxSendApp.h,v 1.10 2009/02/27 18:07:56 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -80,7 +80,7 @@ private:
     void	notifyModemWedged();
     void	notifyCallPlaced(const FaxRequest&);
     void	notifyConnected(const FaxRequest&);
-    void	notifyPageSent(FaxRequest& req, const char* filename);
+    void	notifyPageSent(FaxRequest& req, const char* filename, PageType pt);
     void	notifyDocumentSent(FaxRequest&, u_int fileIndex);
     void	notifyPollRecvd(FaxRequest&, FaxRecvInfo&);
     void	notifyPollDone(FaxRequest&, u_int pollIndex);
