@@ -1,4 +1,4 @@
-/*	$Id: MsgFmt.h,v 1.5 2008/02/11 04:12:22 faxguy Exp $ */
+/*	$Id: MsgFmt.h,v 1.5 2007/09/14 16:30:08 pfournier Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -52,16 +52,12 @@ struct MsgFmt {
 
     static bool getLine(FILE* fd, fxStackBuffer& buf);
     static fxStr stripComments(const fxStr& s);
-    void copyQP(fxStackBuffer& buf, const char line[], u_int cc);
-    void copyBase64(fxStackBuffer& buf, const char line[], u_int cc);
-    void copyUUDecode(fxStackBuffer& buf, const char line[], u_int);
 
     const fxStr* findHeader(const fxStr& name) const;
     u_int headerCount(void);
     fxStr mapHeader(const fxStr& name);
     void parseHeaders(FILE* fd, u_int& lineno);
-    void formatHeaders(TextFormat& fmt);
+    bool formatHeaders(TextFormat& fmt);
     void showItalic(TextFormat& fmt, const char* cp);
-    void decodeRFC2047(fxStr& s);
 };
 #endif /* _MsgFmt_ */
