@@ -1,4 +1,4 @@
-/*	$Id: UnixFaxServer.h,v 1.1.1.1 2005/11/11 21:32:03 faxguy Exp $ */
+/*	$Id: UnixFaxServer.h,v 1.3 2009/01/16 18:57:55 aidan Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -41,7 +41,7 @@ private:
     void passiveCmd(void);
     void netStatus(FILE*);
     bool hostPort();
-    void portCmd(void);
+    void portCmd(Token);
 
     virtual void initServer(void);
 
